sol.printouts -- PDF printouts generators — SoL 4 developers documentation

# `sol.printouts` -- PDF printouts generators

This module uses ReportLab to produce all the needed printouts.

sol.printouts.badgename_style = <ParagraphStyle 'Italic'>

  The style used for the player name on the badges

sol.printouts.base_style = <reportlab.lib.styles.StyleSheet1 object>

  The base style used to build the document

sol.printouts.boardnumber_style = <ParagraphStyle 'Title'>

  The style used for the number of the board

sol.printouts.caption_style = <ParagraphStyle 'Italic'>

  The style used for the caption of the table's columns

sol.printouts.cardinfo_style = <ParagraphStyle 'Italic'>

  The style used for the additional info on the score cards

sol.printouts.cardname_style = <ParagraphStyle 'Italic'>

  The style used for the player name on the score cards

sol.printouts.cardsmall_style = <ParagraphStyle 'Normal'>

  The style used for most of the text on the score cards

sol.printouts.cardtitle_style = <ParagraphStyle 'Normal'>

  The style used for the title of the score cards

sol.printouts.country_width = 25.511811023622048

  The width of the country columns

sol.printouts.heading_style = <ParagraphStyle 'Heading2'>

  The style used for the heading paragraphs of the document

sol.printouts.normal_style = <ParagraphStyle 'Normal'>

  The style used for most of the paragraphs of the document

sol.printouts.prizes_width = 56.69291338582677

  The width of the prizes columns

sol.printouts.rank_width = 22.67716535433071

  The width of the rank columns

sol.printouts.scores_width = 36.8503937007874

  The width of the scores columns

sol.printouts.subtitle_style = <ParagraphStyle 'Heading1'>

  The style used for the subtitle of the document

sol.printouts.title_style = <ParagraphStyle 'Title'>

  The style used for the title of the document